/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2023 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#include "WidgetController.h"

#include <QHBoxLayout>
#include <QLineEdit>
#include <QSpinBox>

#include <U2Core/U2SafePoints.h>

namespace U2 {

WidgetController::WidgetController(WizardController* _wc)
    : wc(_wc) {
}

WidgetController::~WidgetController() {
}

/************************************************************************/
/* LabeledPropertyWidget */
/************************************************************************/
LabeledPropertyWidget::LabeledPropertyWidget(const QString& labelText, PropertyWidget* widget, QWidget* parent)
    : QWidget(parent) {
    setObjectName(labelText + "_propertyWidget");
    auto layout = new QHBoxLayout(this);
    setLayout(layout);

    label = new QLabel(labelText, this);
    label->setObjectName(labelText + " label");
    auto mainWidget = widget->findChild<QWidget*>("mainWidget");
    if (mainWidget != nullptr) {
        mainWidget->setObjectName(labelText + " widget");
    }
    layout->addWidget(label);
    layout->addWidget(widget);

    layout->setContentsMargins(0, 0, 0, 0);
    layout->setSpacing(0);

    layout->setAlignment(label, Qt::AlignTop);
}

void LabeledPropertyWidget::setLabelWidth(int width) {
    SAFE_POINT(label != nullptr, "NULL label", );
    label->setFixedWidth(width);
}

}  // namespace U2
